import React from "react"
import { Link, } from 'gatsby'
import type { FetchResult, } from '../../types'
import NotFoundPage from "./notFound";
import { ResponseStatus } from "../../types";
import api from '../../api'
import { LazyLoadImage } from 'react-lazy-load-image-component';
import 'react-lazy-load-image-component/src/effects/blur.css';

interface Props {
  serverData: { fetchResult: FetchResult }
}
export async function getServerData() {
  const response = await api.fetch();
  return { props: { fetchResult: response } };
}
const Image = () => {
  return (
    <img height={1000} width={640}></img>
  )
}
const SSRProductPage = ({ serverData }: Props) => {
  const { fetchResult } = serverData
  if (fetchResult.status !== ResponseStatus.sucess) {
    return (
      <>
        <NotFoundPage />
      </>
    )
  }
  return (
    <div className='flex-1 max-w-full'>
      <div className="flex -mb-40 lg:-mb-56 col-auto columns-1 gap-1 justify-center flex-wrap basis-1 flex-auto size-auto">
        {fetchResult.data.map((a: any, index: number) => (
          <Link key={`link-order-${index}`} to={a.description.replace(/\s/g, '')}>
            <LazyLoadImage
              src={a.link}
              key={`image-order-${index}`}
              className="my-6 size-auto object-contain"
              alt={a.description}
              height={a.height}
              width={a.width}
              placeholder={<Image />}
              loading={index < 2 ? "eager" : "lazy"}
              threshold={200}
              effect="blur"
            />
          </Link>
        ))}
      </div>

    </div>
  )
}

export default SSRProductPage


